import React, { PureComponent } from 'react';
import calcLinksToDisplay from './calcLinksToDisplay';
import Pagination from 'react-bootstrap/Pagination';
const ELLIPSIS_MARK = -1;
export default class PaginationWrapper extends PureComponent {
    handleClickF(page) {
        return () => {
            const { onChange, name } = this.props;
            if (!onChange) {
                console.warn('onChange() method is not set for PaginationWrapper ("'
                    + name + '"), but page change occurs');
                return;
            }
            return onChange({ target: { name, value: page } });
        };
    }
    render() {
        /* eslint @typescript-eslint/no-unused-vars: [2, {"varsIgnorePattern": "(onChange|name)"}] */
        const { atBeginEnd, aroundCurrent, onChange, disabled, name, readOnly, showFirstLast, showPrevNext, totalPages, value, ...etc } = this.props;
        const linksToDisplay = calcLinksToDisplay(totalPages, value, atBeginEnd, aroundCurrent, ELLIPSIS_MARK);
        const allDisabled = disabled || readOnly;
        return React.createElement(Pagination, Object.assign({}, etc),
            showFirstLast && (value <= 0 || allDisabled
                ? React.createElement(Pagination.First, { disabled: true, key: "-2" })
                : React.createElement(Pagination.First, { key: "-2", onClick: this.handleClickF(0) })),
            showPrevNext && (value <= 0 || allDisabled
                ? React.createElement(Pagination.Prev, { disabled: true, key: "-1" })
                : React.createElement(Pagination.Prev, { key: "-1", onClick: this.handleClickF(value - 1) })),
            linksToDisplay.map((p, index) => p === value
                ? React.createElement(Pagination.Item, { active: true, key: p }, p + 1)
                : p === ELLIPSIS_MARK
                    ? React.createElement(Pagination.Ellipsis, { disabled: true, key: `_${index}` })
                    : allDisabled
                        ? React.createElement(Pagination.Item, { disabled: true, key: p }, p + 1)
                        : React.createElement(Pagination.Item, { href: "#", key: p, onClick: this.handleClickF(p) }, p + 1)),
            showPrevNext && (value >= totalPages - 1 || allDisabled
                ? React.createElement(Pagination.Next, { disabled: true, key: "+1" })
                : React.createElement(Pagination.Next, { key: "+1", onClick: this.handleClickF(value + 1) })),
            showFirstLast && (value >= totalPages - 1 || allDisabled
                ? React.createElement(Pagination.Last, { disabled: true, key: "+2" })
                : React.createElement(Pagination.Last, { key: "+2", onClick: this.handleClickF(totalPages - 1) })));
    }
}
PaginationWrapper.defaultProps = {
    atBeginEnd: 2,
    aroundCurrent: 1,
    name: 'page',
    showFirstLast: true,
    showPrevNext: true,
};
